
// Clock.java
// Andrew Davison, March 2017, ad@fivedots.coe.psu.ac.th

/* Start a clock thread which displays the current time on the
   board, and keeps updating. When the user presses enter, main()
   will wake up and kill the thread.
*/

import java.util.*;


public class Clock extends Thread
{
  private static final int REFRESH_DELAY = 1000 * 20;  // 20 secs in ms

  private volatile boolean isRunning = false;   // used to stop the thread
  private Screen scr;
  private SpriteStore ss;


  public Clock(Screen scr, SpriteStore ss)
  { this.scr = scr;
    this.ss = ss;
    this.start();
  }  // end of Clock


  public void run()
  {
    isRunning = true;
    while(isRunning) {
      scr.clear();
      scr.add( ss.buildMsg(getTime()) );
      scr.draw();
      Utils.delay(REFRESH_DELAY);
    }
  } // end of run()


  public void end()
  {  isRunning = false;   }


  private String getTime()
  // return the current time as a formattted string:
  // <hours> : <mins>
  {
    Calendar cal = new GregorianCalendar();
    int hours = cal.get(Calendar.HOUR); // 0..11
    int mins = cal.get(Calendar.MINUTE); // 0..59
    return String.format("%d:%02d", hours, mins);
  }  // end of getTime()



  // ------------------ test rig ---------------

  public static void main(String[] args)
  {
    Screen scr = new Screen();
    SpriteStore ss = new SpriteStore(SpriteStore.MEDIUM); 
           // font must be small or medium so that all the
           // time text will be visible at once
    Clock c = new Clock(scr, ss);

    Utils.waitEnter();   // look at the clock for a bit...

    c.end();
    scr.close();
  }  // end of main()


}  // end of Clock class

