
// TimeLeft.java
// Andrew Davison, March 2017, ad@fivedots.coe.psu.ac.th

/* Display the number of seconds left between now and a time
   entered by the user on the command line when TimeLeft.java
   is called.
   When the seconds left reaches 0, the message "Time!!" is
   displayed, and a sound played.

   Usage:   run TimeLeft 14:55     (must be in HH:MM format)
*/

import java.util.*;
import java.time.*;
import java.time.temporal.*;
import java.time.format.DateTimeParseException;


public class TimeLeft extends Thread
{
  private static final int REFRESH_DELAY = 1000;  // 1 sec in ms

  private volatile boolean isRunning = false;   // used to stop the thread
  private Screen scr;
  private SpriteStore ss;
  private LocalTime deadline;


  public TimeLeft(Screen scr, SpriteStore ss, String deadlineStr)
  { 
    this.scr = scr;
    this.ss = ss;

    try {
      deadline = LocalTime.parse(deadlineStr);
      this.start();
    }
    catch(DateTimeParseException e)
    {  System.out.println("Incorrect time format; use 24-hour HH:MM");  }
  }  // end of TimeLeft()



  public void run()
  {
    isRunning = true;
    while(isRunning) {
      long secs = secsLeft();
      if (secs <= 0)  // might be -ve
        break;

      scr.clear();
      scr.add(ss.buildMsg("" + secs));
      scr.draw();
      Utils.delay(REFRESH_DELAY);
    }

    // time has run out
    Utils.play("buzz", 4);
    scr.clear();
    scr.add(ss.buildMsg("Time!!"));
    scr.draw();
  } // end of run()


  public void end()
  {  isRunning = false;   }


  private long secsLeft()
  // return seconds left until the deadline time
  { LocalTime now = LocalTime.now();
    return now.until(deadline, ChronoUnit.SECONDS);
  } 


  // -------------------------------------

  public static void main(String[] args)
  {
    if (args.length != 1) {
      System.out.println("usage: run TimeLeft \"<deadline HH:MM 24-hour time>\"");
      return;
    }
    Screen scr = new Screen();
    SpriteStore ss = new SpriteStore(SpriteStore.MEDIUM); 
    TimeLeft c = new TimeLeft(scr, ss, args[0]);

    Utils.waitEnter();
    c.end();
    scr.close();
  }  // end of main()


}  // end of TimeLeft class

