
// LedScreen.java
// Andrew Davison, March 2017, ad@fivedots.coe.psu.ac.th

/* A JFrame around LedPanel where a copy of the Dream Cheeky
   LED Message board is drawn.
*/


import java.awt.*;
import java.awt.event.*;
import javax.swing.*;



public class LedScreen extends JFrame implements Board
{
  private LedPanel pane = null;


  public LedScreen()
  {
    super("Dream Cheeky LED Message Board");

    try {
      UIManager.setLookAndFeel(
            "com.sun.java.swing.plaf.nimbus.NimbusLookAndFeel");
    } 
    catch(Exception e) {}

    Container c = getContentPane();
    c.setLayout( new BoxLayout(c, BoxLayout.Y_AXIS));

    pane = new LedPanel();
    c.add(pane);

    setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    pack();
    setResizable(false);
    setVisible(true);
  } // end of LedScreen()



  public void draw(char[][] scr)
  // pass the screen array to the panel for rendering
  { pane.draw(scr);  } 


  public void close()
  // terminate the JFrame and LedPanel by 'clicking' its close box
  {  dispatchEvent(new WindowEvent(this, WindowEvent.WINDOW_CLOSING));  }


  public boolean isAvailable()
  {  return true;  }


  public Dimension getBoardSize()
  // get the board size from the pane
  {  return pane.getBoardSize();  }



  // for stand-alone testing from main()
  public void set(int x, int y, boolean isOn)
  {  pane.set(x, y, isOn);  }



  // -------------- test rig ----------------


  public static void main(String[] args)
  { 
    LedScreen scr = new LedScreen();
    scr.set(5, 5, true);
    scr.set(6, 5, true);
    scr.set(7, 5, true);
    scr.set(7, 4, true);
    scr.set(7, 3, true);

    // Utils.delay(2000);
    // scr.close();
  }   // end of main()


} // end of LedScreen class


